# Rbxthon

Rbxthon is an Open-Source Roblox API built using Python

Why should you use Rbxthon:
- Rbxthon offers amazing documentation
- Rbxthon is super easy to use
- We're open-source

> Visit our github [here](https://github.com/gordxn/RbxThon)